==============================
Abaqus CAE Display Preferences
==============================

Display preferences commands are used to edit the Abaqus/CAE preferences file, `abaqus_2021.gpr`.

Object features
---------------

CaeGuiPrefs
~~~~~~~~~~~

.. autoclass:: abaqus.AbaqusCAEDisplayPreferences.CaeGuiPrefs.CaeGuiPrefs
    :members:

    .. autoclasstoc::

CaeKerPrefs
~~~~~~~~~~~

.. autoclass:: abaqus.AbaqusCAEDisplayPreferences.CaeKerPrefs.CaeKerPrefs
    :members:

    .. autoclasstoc::

caePrefsAccess
~~~~~~~~~~~~~~

.. automodule:: abaqus.AbaqusCAEDisplayPreferences.caePrefsAccess
    :members:
